@@ -437,6 +437,8 @@ class CaenN6725(object):
                 events = []
                 for ch in range(8):
                     events.append(self.digitizer.get_last_waveform(ch))
+                time.sleep(1)
+                detla_t += 1 
             else:
                 events = self.digitizer.readout_and_return()
             delta_t += time.monotonic() - last 
